Welcome to ClientVPS Mirrors

Help for package JMI
Type: Package
Title: Jackknife Mutual Information
Version: 0.1.0
Author: Zeng Xianli <a0123862@u.nus.edu>, Hang Weiqiang <e0010758@u.nus.edu>
Maintainer: Zeng Xianli <a0123862@u.nus.edu>
Description: Computes the Jackknife Mutual Information (JMI) between two random vectors and provides the p-value for dependence tests. See Zeng, X., Xia, Y. and Tong, H. (2018) <doi:10.1073/pnas.1715593115>.
License: GPL-2 | GPL-3 [expanded from: GPL (≥ 2)]
Encoding: UTF-8
LazyData: true
Imports: Rcpp
LinkingTo: Rcpp, RcppArmadillo
RoxygenNote: 6.0.1
NeedsCompilation: yes
Packaged: 2018-10-15 08:00:58 UTC; weiqianghang
Repository: CRAN
Date/Publication: 2018-10-19 15:10:12 UTC

Jackknife Mutual Information

Description

This function provides method for dependence test. It uses permutation test to determine the rejection region.

Usage

JMI(x, y, BN = 1000)

Arguments

x

n by p sample matrix.

y

n by q sample matrix.

BN

Number of permutations, the default value is 1000.

Value

the output is a list which contains:

References

Zeng, X., Xia, Y., & Tong, H. (2018). Jackknife approach to the estimation of mutual information[J]. Proceedings of the National Academy of Sciences, 201715593.

Examples

 x <- matrix(rnorm(50*3),50,3)
 y <- matrix(rnorm(50*2),50,2)
 #calculate the Jackknife Mutual information between x and y.
 JMI(x,y,0)$mi
 #calculate the p-value of independent test between x and y that based on 500 permutations.
 JMI(x,y,500)$pvalue


Need a high-speed mirror for your open-source project?
Contact our mirror admin team at info@clientvps.com.

This archive is provided as a free public service to the community.
Proudly supported by infrastructure from VPSPulse , RxServers , BuyNumber , UnitVPS , OffshoreName and secure payment technology by ArionPay.